function [data, varargout] = ReadRiver(file_name,varargin)
% ReadRiver - Read a HYDROTREND 2.2 output file.
%
%  RivData{1} - River velocity (m/s)
%  RivData{2} - River width (m)
%  RivData{3} - River depth (m)
%  RivData{4} - Bed Load flux (kg/s)
%  RivData{5} - Suspended load Concentration (g/m^3)
%
% See also PlotRiver
%
   
   [nSeasons maxYear nGrains]=RiverInfo(file_name);
   
   maxRecord = nSeasons*maxYear;
   startRecord=1;
   
   if nargin == 1
      nRecords = maxRecord;
   else
      if ( max(size(varargin{1}))==1 )
         nRecords=varargin{1};
         startRecord=1;
      else
         startRecord=varargin{1}(1);
         nRecords=varargin{1}(2)-startRecord;
      end
   end
   
   if ( startRecord+nRecords > maxRecord ) 
      nRecords=maxRecord-startRecord;
   end
   
   fid=fopen(file_name);
   if ( fid < 0 )
      error_str=sprintf('Can not open file %s',file_name);
      error(error_str);
      data = -1;
      for i=1:nargout
         varargout{i}=-1;
      end
   end
   
   
   skipHeader(fid);
%%%   
%%% Skip the first startSample records.
%%%
   skipRiverRecord(fid,nGrains,startRecord-1);
   
   valuesPerRecord = 4+nGrains;
   
   data = fread(fid,[valuesPerRecord nRecords],'float');
   
   data=num2cell(data,2);
   
   fclose(fid);
   
   if nargout == 2
      varargout{1} = nSeasons;
   end

function skipHeader(fid)

   commentBytes = fread(fid,1,'int');
   fread(fid,commentBytes,'char');
   nGrains = fread(fid,3,'int');

function skipRiverRecord(fid,nGrains,skipRecords)
	
	bytesPerRecord = (4+nGrains)*4;
	fseek(fid,bytesPerRecord*skipRecords,'cof');
